summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorMarty Gloff <mgloff@us.ibm.com>2018-03-29 08:49:39 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2018-04-04 14:56:54 -0400
commitfef105cbd664203857cb4ff11585202a6cee29b1 (patch)
treecfe0319090724d0e6d33a07d57a4f48b8b1ee803 /src/include
parente3bff0327790672a3f84b0677624fe7dbe13ccd4 (diff)
downloadtalos-hostboot-fef105cbd664203857cb4ff11585202a6cee29b1.tar.gz
talos-hostboot-fef105cbd664203857cb4ff11585202a6cee29b1.zip
Resolve NodeInfo Naming Conflict
Both TargetService and AttrRP have variables and typedefs with various forms of 'NodeInfo' in their names. To reduce confusion and possible conflicts, names in TargetService are being changed. Change-Id: Iab1dd624a0e9c1f80e8dbcdf500e25b51f02a48a RTC: 142908 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/56454 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Prachi Gupta <pragupta@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/include')
-rw-r--r--src/include/usr/targeting/common/targetservice.H12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/include/usr/targeting/common/targetservice.H b/src/include/usr/targeting/common/targetservice.H
index 2c8133ae8..04bcc8657 100644
--- a/src/include/usr/targeting/common/targetservice.H
+++ b/src/include/usr/targeting/common/targetservice.H
@@ -823,7 +823,7 @@ class TargetService
/**
* @brief Node Specific information container
*/
- typedef std::vector< NodeSpecificInfo > NodeInfo_t;
+ typedef std::vector< NodeSpecificInfo > NodeData_t;
/**
* @brief Returns the first Target from the first initialized node
@@ -867,7 +867,7 @@ class TargetService
* on the PNOR (or override) image, and updates the target service to
* point to the start of the target array, wherever it may reside
*
* @param[in] i_nodeInfoContainer, struct to contain all node
* specific information of the type NodeSpecificInfo. May refer to
* structure definition
*
@@ -878,7 +878,7 @@ class TargetService
*
* @post Target service target pool configured for access
*/
- void _configureTargetPool(NodeSpecificInfo& i_nodeInfoContainer,
+ void _configureTargetPool(NodeSpecificInfo& i_nodeContainer,
AttrRP *i_attrRP = NULL);
/**
@@ -888,7 +888,7 @@ class TargetService
* Computes the maximum number of targets possible based on the PNOR
* (or override) image and returns it to the caller
*
* @param[in/out] io_nodeInfoContainer, struct to contain all node
* specific information of the type NodeSpecificInfo. May refer to
* structure definition
*
@@ -901,7 +901,7 @@ class TargetService
* nodeContainer.
*
*/
- void _maxTargets(NodeSpecificInfo & io_nodeInfoContainer,
+ void _maxTargets(NodeSpecificInfo & io_nodeContainer,
AttrRP *i_attrRP = NULL);
@@ -971,7 +971,7 @@ class TargetService
bool iv_initialized; ///< Is service initialized or not
Target * iv_pSys; // Top Level Target
- NodeInfo_t iv_nodeInfo;
+ NodeData_t iv_nodeData;
// Disable copy constructor / assignment operator
OpenPOWER on IntegriCloud
@@ -867,7 +867,7 @@ class TargetService
* point to the start of the target array, wherever it may reside
*
- * @param[in] i_nodeInfoContainer, struct to contain all node
+ * @param[in] i_nodeContainer, struct to contain all node
* specific information of the type NodeSpecificInfo. May refer to
* structure definition
@@ -888,7 +888,7 @@ class TargetService
* (or override) image and returns it to the caller
*
- * @param[in/out] io_nodeInfoContainer, struct to contain all node
+ * @param[in/out] io_nodeContainer, struct to contain all node
* specific information of the type NodeSpecificInfo. May refer to
* structure definition